@@ -233,6 +233,17 @@ def inspect_collection(collection: "ElementCollection", limit: int = 30) -> Insp
         # Get appropriate columns for this type
         columns = _get_columns_for_type(element_type, show_page_column)
 
+        # Add checkbox state column if we have checkbox regions
+        if element_type == "region" and any(
+            getattr(e, "region_type", "") == "checkbox" for e in display_elements
+        ):
+            # Insert state column after type column
+            if "type" in columns:
+                type_idx = columns.index("type")
+                columns.insert(type_idx + 1, "state")
+            else:
+                columns.append("state")
+
         # Extract data for each element
         element_data = []
         for element in display_elements:
@@ -272,17 +283,12 @@ def _get_columns_for_type(element_type: str, show_page_column: bool) -> List[str
                 "font_family",
                 "font_variant",
                 "size",
-                "bold",
-                "italic",
-                "strike",
-                "underline",
-                "highlight",
+                "styles",
                 "source",
                 "confidence",
+                "color",
             ]
         )
-        # Add foreground text colour too
-        columns.append("color")
     elif element_type == "rect":
         columns = base_columns + ["width", "height", "stroke", "fill", "stroke_width"]
     elif element_type == "line":
@@ -358,6 +364,52 @@ def _extract_element_value(element: "Element", column: str) -> Any:
                 return str(col_val)
             return ""
 
+        elif column == "styles":
+            # Collect all active text decorations
+            styles = []
+
+            if getattr(element, "bold", False):
+                styles.append("bold")
+            if getattr(element, "italic", False):
+                styles.append("italic")
+            if getattr(element, "strike", False):
+                styles.append("strike")
+            if getattr(element, "underline", False):
+                styles.append("underline")
+
+            # Handle highlight specially - include color if not default yellow
+            if getattr(element, "is_highlighted", False):
+                highlight_color = getattr(element, "highlight_color", None)
+                if highlight_color is not None:
+                    # Convert color to hex if needed
+                    if isinstance(highlight_color, (tuple, list)) and len(highlight_color) >= 3:
+                        try:
+                            r, g, b = [
+                                int(v * 255) if v <= 1 else int(v) for v in highlight_color[:3]
+                            ]
+                            hex_color = f"#{r:02x}{g:02x}{b:02x}"
+                            styles.append(f"highlight({hex_color})")
+                        except Exception:
+                            styles.append("highlight")
+                    elif isinstance(highlight_color, (int, float)):
+                        # Grayscale value
+                        try:
+                            gray = (
+                                int(highlight_color * 255)
+                                if highlight_color <= 1
+                                else int(highlight_color)
+                            )
+                            hex_color = f"#{gray:02x}{gray:02x}{gray:02x}"
+                            styles.append(f"highlight({hex_color})")
+                        except Exception:
+                            styles.append("highlight")
+                    else:
+                        styles.append("highlight")
+                else:
+                    styles.append("highlight")
+
+            return ", ".join(styles) if styles else ""
+
         elif column in ["stroke", "fill", "color"]:
             value = getattr(element, column, None)
             # If already a string (e.g. '#ff00aa' or 'red') return as is
@@ -382,6 +434,15 @@ def _extract_element_value(element: "Element", column: str) -> Any:
             value = getattr(element, column, False)
             return value if isinstance(value, bool) else False
 
+        elif column == "state":
+            # For checkbox regions, show checked/unchecked state
+            if getattr(element, "region_type", "") == "checkbox":
+                if hasattr(element, "is_checked"):
+                    return "checked" if element.is_checked else "unchecked"
+                elif hasattr(element, "checkbox_state"):
+                    return element.checkbox_state
+            return ""
+
         else:
             # Generic attribute access
             value = getattr(element, column, "")
